@@ -187,27 +187,72 @@ impl VisitMut for Remapper {
 }
 
 pub(crate) struct MultiReplacer<'a> {
-    pub vars: &'a mut FxHashMap<Id, Box<Expr>>,
-    pub changed: bool,
+    vars: &'a mut FxHashMap<Id, Box<Expr>>,
+    changed: bool,
+    clone: bool,
+    only_callee: bool,
+    worked: &'a mut bool,
 }
 
-impl MultiReplacer<'_> {
+impl<'a> MultiReplacer<'a> {
+    /// `worked` will be changed to `true` if any replacement is done
+    pub fn new(
+        vars: &'a mut FxHashMap<Id, Box<Expr>>,
+        clone: bool,
+        only_callee: bool,
+        worked: &'a mut bool,
+    ) -> Self {
+        MultiReplacer {
+            vars,
+            changed: false,
+            clone,
+            only_callee,
+            worked,
+        }
+    }
+
     fn var(&mut self, i: &Id) -> Option<Box<Expr>> {
-        self.vars.remove(i)
+        if self.clone {
+            self.vars.get(i).cloned()
+        } else {
+            self.vars.remove(i)
+        }
     }
 }
 
 impl VisitMut for MultiReplacer<'_> {
     noop_visit_mut_type!();
 
+    fn visit_mut_callee(&mut self, e: &mut Callee) {
+        e.visit_mut_children_with(self);
+
+        if self.only_callee {
+            if let Callee::Expr(e) = e {
+                if let Expr::Ident(i) = &**e {
+                    if let Some(new) = self.var(&i.to_id()) {
+                        debug!("multi-replacer: Replaced `{}`", i);
+                        *self.worked = true;
+                        self.changed = true;
+
+                        **e = *new;
+                    }
+                }
+            }
+        }
+    }
+
     fn visit_mut_expr(&mut self, e: &mut Expr) {
         e.visit_mut_children_with(self);
 
-        if let Expr::Ident(i) = e {
-            if let Some(new) = self.var(&i.to_id()) {
-                debug!("multi-replacer: Replaced `{}`", i);
-                *e = *new;
-                self.changed = true;
+        if !self.only_callee {
+            if let Expr::Ident(i) = e {
+                if let Some(new) = self.var(&i.to_id()) {
+                    debug!("multi-replacer: Replaced `{}`", i);
+                    *self.worked = true;
+                    self.changed = true;
+
+                    *e = *new;
+                }
             }
         }
     }
@@ -236,10 +281,14 @@ impl VisitMut for MultiReplacer<'_> {
         if let Prop::Shorthand(i) = p {
             if let Some(value) = self.var(&i.to_id()) {
                 debug!("multi-replacer: Replaced `{}` as shorthand", i);
+                *self.worked = true;
                 self.changed = true;
 
                 *p = Prop::KeyValue(KeyValueProp {
-                    key: PropName::Ident(i.clone()),
+                    key: PropName::Ident(Ident::new(
+                        i.sym.clone(),
+                        i.span.with_ctxt(Default::default()),
+                    )),
                     value,
                 });
             }
